using System.Reflection;
using UlstuGosApi;

var builder = WebApplication.CreateBuilder(args);

builder.Host.UseSystemd();

builder.Services.AddEndpointsApiExplorer();
builder.Services.AddSwaggerGen(options =>
{
    var xmlFilename = $"{Assembly.GetExecutingAssembly().GetName().Name}.xml";
    options.IncludeXmlComments(Path.Combine(AppContext.BaseDirectory, xmlFilename));
});
builder.Services.AddCors(options =>
{
    options.AddDefaultPolicy(
        policy =>
        {
            policy
                .AllowAnyOrigin()
                .AllowAnyHeader()
                .AllowAnyMethod();
        });
});

var app = builder.Build();

app.UseSwagger();
app.UseSwaggerUI();

app.UseCors();

app.MapGet("/", () => Results.LocalRedirect("/swagger"))
    .ExcludeFromDescription();

app.MapGroup("/timetable")
    .AddTimeTable()
    .WithTags("TimeTable");

app.MapGroup("/weather")
    .AddWeather()
    .WithTags("Weather");

app.Run();
